Django Phaxio
-------------

.. automodule:: django_phaxio
    :members:
    :undoc-members:
    :show-inheritance:

All Contents
============

Contents:

.. toctree::
   :maxdepth: 2
   :glob:

   *

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
